Documentation
¶
Index ¶
- func AppProfile_DataBoostIsolationReadOnly_ComputeBillingOwner_ToProto(mapCtx *direct.MapContext, in *string) *pb.AppProfile_DataBoostIsolationReadOnly_ComputeBillingOwner
- func AppProfile_DataBoostIsolationReadOnly_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile_DataBoostIsolationReadOnly) *krmv1beta1.AppProfile_DataBoostIsolationReadOnly
- func AppProfile_DataBoostIsolationReadOnly_ToProto(mapCtx *direct.MapContext, ...) *pb.AppProfile_DataBoostIsolationReadOnly
- func AppProfile_MultiClusterRoutingUseAny_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile_MultiClusterRoutingUseAny) *krmv1beta1.AppProfile_MultiClusterRoutingUseAny
- func AppProfile_MultiClusterRoutingUseAny_RowAffinity_FromProto(mapCtx *direct.MapContext, ...) *krmv1beta1.AppProfile_MultiClusterRoutingUseAny_RowAffinity
- func AppProfile_MultiClusterRoutingUseAny_RowAffinity_ToProto(mapCtx *direct.MapContext, ...) *pb.AppProfile_MultiClusterRoutingUseAny_RowAffinity
- func AppProfile_MultiClusterRoutingUseAny_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.AppProfile_MultiClusterRoutingUseAny) *pb.AppProfile_MultiClusterRoutingUseAny
- func AppProfile_Priority_ToProto(mapCtx *direct.MapContext, in *string) *pb.AppProfile_Priority_
- func AppProfile_SingleClusterRouting_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile_SingleClusterRouting) *krmv1beta1.AppProfile_SingleClusterRouting
- func AppProfile_SingleClusterRouting_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.AppProfile_SingleClusterRouting) *pb.AppProfile_SingleClusterRouting
- func AppProfile_StandardIsolation_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile_StandardIsolation) *krmv1beta1.AppProfile_StandardIsolation
- func AppProfile_StandardIsolation_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.AppProfile_StandardIsolation) *pb.AppProfile_StandardIsolation
- func AuthorizedView_FamilySubsets_FromProto(mapCtx *direct.MapContext, in *pb.AuthorizedView_FamilySubsets) *krm.AuthorizedView_FamilySubsets
- func AuthorizedView_FamilySubsets_ToProto(mapCtx *direct.MapContext, in *krm.AuthorizedView_FamilySubsets) *pb.AuthorizedView_FamilySubsets
- func AuthorizedView_SubsetView_FromProto(mapCtx *direct.MapContext, in *pb.AuthorizedView_SubsetView) *krm.AuthorizedView_SubsetView
- func AuthorizedView_SubsetView_ToProto(mapCtx *direct.MapContext, in *krm.AuthorizedView_SubsetView) *pb.AuthorizedView_SubsetView
- func AutomatedBackupPolicy_Frequency_FromProto(mapCtx *direct.MapContext, in *durationpb.Duration) *string
- func AutomatedBackupPolicy_Frequency_ToProto(mapCtx *direct.MapContext, in *string) *durationpb.Duration
- func AutomatedBackupPolicy_RetentionPeriod_FromProto(mapCtx *direct.MapContext, in *durationpb.Duration) *string
- func AutomatedBackupPolicy_RetentionPeriod_ToProto(mapCtx *direct.MapContext, in *string) *durationpb.Duration
- func AutoscalingLimits_FromProto(mapCtx *direct.MapContext, in *pb.AutoscalingLimits) *krm.AutoscalingLimits
- func AutoscalingLimits_ToProto(mapCtx *direct.MapContext, in *krm.AutoscalingLimits) *pb.AutoscalingLimits
- func AutoscalingTargets_FromProto(mapCtx *direct.MapContext, in *pb.AutoscalingTargets) *krm.AutoscalingTargets
- func AutoscalingTargets_ToProto(mapCtx *direct.MapContext, in *krm.AutoscalingTargets) *pb.AutoscalingTargets
- func BackupInfo_EndTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func BackupInfo_EndTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func BackupInfo_StartTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func BackupInfo_StartTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func Backup_EndTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func Backup_EndTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func Backup_ExpireTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func Backup_ExpireTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func Backup_StartTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func Backup_StartTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func BigtableAppProfileObservedState_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile) *krmv1beta1.BigtableAppProfileObservedState
- func BigtableAppProfileObservedState_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.BigtableAppProfileObservedState) *pb.AppProfile
- func BigtableAppProfileSpec_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile) *krmv1beta1.BigtableAppProfileSpec
- func BigtableAppProfileSpec_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.BigtableAppProfileSpec) *pb.AppProfile
- func BigtableAuthorizedViewObservedState_FromProto(mapCtx *direct.MapContext, in *pb.AuthorizedView) *krmv1alpha1.BigtableAuthorizedViewObservedState
- func BigtableAuthorizedViewObservedState_ToProto(mapCtx *direct.MapContext, in *krmv1alpha1.BigtableAuthorizedViewObservedState) *pb.AuthorizedView
- func BigtableAuthorizedViewSpec_FromProto(mapCtx *direct.MapContext, in *pb.AuthorizedView) *krm.BigtableAuthorizedViewSpec
- func BigtableAuthorizedViewSpec_ToProto(mapCtx *direct.MapContext, in *krm.BigtableAuthorizedViewSpec) *pb.AuthorizedView
- func BigtableBackupObservedState_FromProto(mapCtx *direct.MapContext, in *pb.Backup) *krm.BigtableBackupObservedState
- func BigtableBackupObservedState_ToProto(mapCtx *direct.MapContext, in *krm.BigtableBackupObservedState) *pb.Backup
- func BigtableBackupSpec_FromProto(mapCtx *direct.MapContext, in *pb.Backup) *krm.BigtableBackupSpec
- func BigtableBackupSpec_ToProto(mapCtx *direct.MapContext, in *krm.BigtableBackupSpec) *pb.Backup
- func BigtableClusterFuzzer() fuzztesting.KRMFuzzer
- func BigtableClusterObservedState_FromProto(mapCtx *direct.MapContext, in *pb.Cluster) *krm.BigtableClusterObservedState
- func BigtableClusterObservedState_ToProto(mapCtx *direct.MapContext, in *krm.BigtableClusterObservedState) *pb.Cluster
- func BigtableClusterSpec_FromProto(mapCtx *direct.MapContext, in *pb.Cluster) *krm.BigtableClusterSpec
- func BigtableClusterSpec_ToProto(mapCtx *direct.MapContext, in *krm.BigtableClusterSpec) *pb.Cluster
- func BigtableInstanceSpec_FromProto(mapCtx *direct.MapContext, in *pb.Instance) *krm.BigtableInstanceSpec
- func BigtableInstanceSpec_ToProto(mapCtx *direct.MapContext, in *krm.BigtableInstanceSpec) *pb.Instance
- func BigtableLogicalViewObservedState_FromProto(mapCtx *direct.MapContext, in *pb.LogicalView) *krmv1alpha1.BigtableLogicalViewObservedState
- func BigtableLogicalViewObservedState_ToProto(mapCtx *direct.MapContext, in *krmv1alpha1.BigtableLogicalViewObservedState) *pb.LogicalView
- func BigtableLogicalViewSpec_FromProto(mapCtx *direct.MapContext, in *pb.LogicalView) *krmv1alpha1.BigtableLogicalViewSpec
- func BigtableLogicalViewSpec_ToProto(mapCtx *direct.MapContext, in *krmv1alpha1.BigtableLogicalViewSpec) *pb.LogicalView
- func ChangeStreamConfig_RetentionPeriod_FromProto(mapCtx *direct.MapContext, in *durationpb.Duration) *string
- func ChangeStreamConfig_RetentionPeriod_ToProto(mapCtx *direct.MapContext, in *string) *durationpb.Duration
- func Cluster_ClusterAutoscalingConfig_FromProto(mapCtx *direct.MapContext, in *pb.Cluster_ClusterAutoscalingConfig) *krm.Cluster_ClusterAutoscalingConfig
- func Cluster_ClusterAutoscalingConfig_ToProto(mapCtx *direct.MapContext, in *krm.Cluster_ClusterAutoscalingConfig) *pb.Cluster_ClusterAutoscalingConfig
- func Cluster_ClusterConfig_FromProto(mapCtx *direct.MapContext, in *pb.Cluster_ClusterConfig) *krm.Cluster_ClusterConfig
- func Cluster_ClusterConfig_ToProto(mapCtx *direct.MapContext, in *krm.Cluster_ClusterConfig) *pb.Cluster_ClusterConfig
- func Cluster_EncryptionConfig_FromProto(mapCtx *direct.MapContext, in *pb.Cluster_EncryptionConfig) *krm.Cluster_EncryptionConfig
- func Cluster_EncryptionConfig_ToProto(mapCtx *direct.MapContext, in *krm.Cluster_EncryptionConfig) *pb.Cluster_EncryptionConfig
- func EncryptionInfoObservedState_FromProto(mapCtx *direct.MapContext, in *pb.EncryptionInfo) *krm.EncryptionInfoObservedState
- func EncryptionInfoObservedState_ToProto(mapCtx *direct.MapContext, in *krm.EncryptionInfoObservedState) *pb.EncryptionInfo
- func EncryptionInfo_EncryptionStatus_FromProto(mapCtx *direct.MapContext, in *status.Status) *string
- func EncryptionInfo_EncryptionStatus_ToProto(mapCtx *direct.MapContext, in *string) *status.Status
- func EncryptionInfo_FromProto(mapCtx *direct.MapContext, in *pb.EncryptionInfo) *krmv1beta1.EncryptionInfo
- func EncryptionInfo_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.EncryptionInfo) *pb.EncryptionInfo
- func GcRule_MaxAge_FromProto(mapCtx *direct.MapContext, in *durationpb.Duration) *string
- func GcRule_MaxAge_ToProto(mapCtx *direct.MapContext, in *string) *durationpb.Duration
- func GcRule_MaxNumVersions_ToProto(mapCtx *direct.MapContext, in *int32) *pb.GcRule_MaxNumVersions
- func HasHTTPCode(err error, code int) bool
- func HotTablet_EndTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func HotTablet_EndTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func HotTablet_StartTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func HotTablet_StartTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func Instance_CreateTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func Instance_CreateTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func Instance_SatisfiesPzs_ToProto(mapCtx *direct.MapContext, in *bool) *bool
- func IsNotFound(err error) bool
- func NewBigtableAppProfileModel(ctx context.Context, config *config.ControllerConfig) (directbase.Model, error)
- func NewLogicalViewModel(ctx context.Context, config *config.ControllerConfig) (directbase.Model, error)
- func OperationProgress_EndTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func OperationProgress_EndTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func OperationProgress_StartTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func OperationProgress_StartTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func PtrTo[T any](t T) *T
- func Snapshot_CreateTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func Snapshot_CreateTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func Snapshot_DeleteTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
- func Snapshot_DeleteTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
- func ValueOf[T any](p *T) T
- type BigtableAppProfileAdapter
- func (a *BigtableAppProfileAdapter) Create(ctx context.Context, createOp *directbase.CreateOperation) error
- func (a *BigtableAppProfileAdapter) Delete(ctx context.Context, deleteOp *directbase.DeleteOperation) (bool, error)
- func (a *BigtableAppProfileAdapter) Export(ctx context.Context) (*unstructured.Unstructured, error)
- func (a *BigtableAppProfileAdapter) Find(ctx context.Context) (bool, error)
- func (a *BigtableAppProfileAdapter) Update(ctx context.Context, updateOp *directbase.UpdateOperation) error
- type LogicalViewAdapter
- func (a *LogicalViewAdapter) Create(ctx context.Context, createOp *directbase.CreateOperation) error
- func (a *LogicalViewAdapter) Delete(ctx context.Context, deleteOp *directbase.DeleteOperation) (bool, error)
- func (a *LogicalViewAdapter) Export(ctx context.Context) (*unstructured.Unstructured, error)
- func (a *LogicalViewAdapter) Find(ctx context.Context) (bool, error)
- func (a *LogicalViewAdapter) Update(ctx context.Context, updateOp *directbase.UpdateOperation) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AppProfile_DataBoostIsolationReadOnly_ComputeBillingOwner_ToProto ¶
func AppProfile_DataBoostIsolationReadOnly_ComputeBillingOwner_ToProto(mapCtx *direct.MapContext, in *string) *pb.AppProfile_DataBoostIsolationReadOnly_ComputeBillingOwner
func AppProfile_DataBoostIsolationReadOnly_FromProto ¶
func AppProfile_DataBoostIsolationReadOnly_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile_DataBoostIsolationReadOnly) *krmv1beta1.AppProfile_DataBoostIsolationReadOnly
func AppProfile_DataBoostIsolationReadOnly_ToProto ¶
func AppProfile_DataBoostIsolationReadOnly_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.AppProfile_DataBoostIsolationReadOnly) *pb.AppProfile_DataBoostIsolationReadOnly
func AppProfile_MultiClusterRoutingUseAny_FromProto ¶
func AppProfile_MultiClusterRoutingUseAny_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile_MultiClusterRoutingUseAny) *krmv1beta1.AppProfile_MultiClusterRoutingUseAny
func AppProfile_MultiClusterRoutingUseAny_RowAffinity_FromProto ¶ added in v1.131.0
func AppProfile_MultiClusterRoutingUseAny_RowAffinity_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile_MultiClusterRoutingUseAny_RowAffinity) *krmv1beta1.AppProfile_MultiClusterRoutingUseAny_RowAffinity
func AppProfile_MultiClusterRoutingUseAny_RowAffinity_ToProto ¶ added in v1.131.0
func AppProfile_MultiClusterRoutingUseAny_RowAffinity_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.AppProfile_MultiClusterRoutingUseAny_RowAffinity) *pb.AppProfile_MultiClusterRoutingUseAny_RowAffinity
func AppProfile_MultiClusterRoutingUseAny_ToProto ¶
func AppProfile_MultiClusterRoutingUseAny_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.AppProfile_MultiClusterRoutingUseAny) *pb.AppProfile_MultiClusterRoutingUseAny
func AppProfile_Priority_ToProto ¶
func AppProfile_Priority_ToProto(mapCtx *direct.MapContext, in *string) *pb.AppProfile_Priority_
func AppProfile_SingleClusterRouting_FromProto ¶
func AppProfile_SingleClusterRouting_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile_SingleClusterRouting) *krmv1beta1.AppProfile_SingleClusterRouting
func AppProfile_SingleClusterRouting_ToProto ¶
func AppProfile_SingleClusterRouting_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.AppProfile_SingleClusterRouting) *pb.AppProfile_SingleClusterRouting
func AppProfile_StandardIsolation_FromProto ¶
func AppProfile_StandardIsolation_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile_StandardIsolation) *krmv1beta1.AppProfile_StandardIsolation
func AppProfile_StandardIsolation_ToProto ¶
func AppProfile_StandardIsolation_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.AppProfile_StandardIsolation) *pb.AppProfile_StandardIsolation
func AuthorizedView_FamilySubsets_FromProto ¶
func AuthorizedView_FamilySubsets_FromProto(mapCtx *direct.MapContext, in *pb.AuthorizedView_FamilySubsets) *krm.AuthorizedView_FamilySubsets
func AuthorizedView_FamilySubsets_ToProto ¶
func AuthorizedView_FamilySubsets_ToProto(mapCtx *direct.MapContext, in *krm.AuthorizedView_FamilySubsets) *pb.AuthorizedView_FamilySubsets
func AuthorizedView_SubsetView_FromProto ¶
func AuthorizedView_SubsetView_FromProto(mapCtx *direct.MapContext, in *pb.AuthorizedView_SubsetView) *krm.AuthorizedView_SubsetView
func AuthorizedView_SubsetView_ToProto ¶
func AuthorizedView_SubsetView_ToProto(mapCtx *direct.MapContext, in *krm.AuthorizedView_SubsetView) *pb.AuthorizedView_SubsetView
func AutomatedBackupPolicy_Frequency_FromProto ¶
func AutomatedBackupPolicy_Frequency_FromProto(mapCtx *direct.MapContext, in *durationpb.Duration) *string
func AutomatedBackupPolicy_Frequency_ToProto ¶
func AutomatedBackupPolicy_Frequency_ToProto(mapCtx *direct.MapContext, in *string) *durationpb.Duration
func AutomatedBackupPolicy_RetentionPeriod_FromProto ¶
func AutomatedBackupPolicy_RetentionPeriod_FromProto(mapCtx *direct.MapContext, in *durationpb.Duration) *string
func AutomatedBackupPolicy_RetentionPeriod_ToProto ¶
func AutomatedBackupPolicy_RetentionPeriod_ToProto(mapCtx *direct.MapContext, in *string) *durationpb.Duration
func AutoscalingLimits_FromProto ¶
func AutoscalingLimits_FromProto(mapCtx *direct.MapContext, in *pb.AutoscalingLimits) *krm.AutoscalingLimits
func AutoscalingLimits_ToProto ¶
func AutoscalingLimits_ToProto(mapCtx *direct.MapContext, in *krm.AutoscalingLimits) *pb.AutoscalingLimits
func AutoscalingTargets_FromProto ¶
func AutoscalingTargets_FromProto(mapCtx *direct.MapContext, in *pb.AutoscalingTargets) *krm.AutoscalingTargets
func AutoscalingTargets_ToProto ¶
func AutoscalingTargets_ToProto(mapCtx *direct.MapContext, in *krm.AutoscalingTargets) *pb.AutoscalingTargets
func BackupInfo_EndTime_FromProto ¶
func BackupInfo_EndTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func BackupInfo_EndTime_ToProto ¶
func BackupInfo_EndTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func BackupInfo_StartTime_FromProto ¶
func BackupInfo_StartTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func BackupInfo_StartTime_ToProto ¶
func BackupInfo_StartTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func Backup_EndTime_FromProto ¶
func Backup_EndTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func Backup_EndTime_ToProto ¶
func Backup_EndTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func Backup_ExpireTime_FromProto ¶
func Backup_ExpireTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func Backup_ExpireTime_ToProto ¶
func Backup_ExpireTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func Backup_StartTime_FromProto ¶
func Backup_StartTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func Backup_StartTime_ToProto ¶
func Backup_StartTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func BigtableAppProfileObservedState_FromProto ¶ added in v1.131.0
func BigtableAppProfileObservedState_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile) *krmv1beta1.BigtableAppProfileObservedState
func BigtableAppProfileObservedState_ToProto ¶ added in v1.131.0
func BigtableAppProfileObservedState_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.BigtableAppProfileObservedState) *pb.AppProfile
func BigtableAppProfileSpec_FromProto ¶ added in v1.131.0
func BigtableAppProfileSpec_FromProto(mapCtx *direct.MapContext, in *pb.AppProfile) *krmv1beta1.BigtableAppProfileSpec
func BigtableAppProfileSpec_ToProto ¶ added in v1.131.0
func BigtableAppProfileSpec_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.BigtableAppProfileSpec) *pb.AppProfile
func BigtableAuthorizedViewObservedState_FromProto ¶ added in v1.131.0
func BigtableAuthorizedViewObservedState_FromProto(mapCtx *direct.MapContext, in *pb.AuthorizedView) *krmv1alpha1.BigtableAuthorizedViewObservedState
func BigtableAuthorizedViewObservedState_ToProto ¶ added in v1.131.0
func BigtableAuthorizedViewObservedState_ToProto(mapCtx *direct.MapContext, in *krmv1alpha1.BigtableAuthorizedViewObservedState) *pb.AuthorizedView
func BigtableAuthorizedViewSpec_FromProto ¶ added in v1.130.1
func BigtableAuthorizedViewSpec_FromProto(mapCtx *direct.MapContext, in *pb.AuthorizedView) *krm.BigtableAuthorizedViewSpec
func BigtableAuthorizedViewSpec_ToProto ¶ added in v1.130.1
func BigtableAuthorizedViewSpec_ToProto(mapCtx *direct.MapContext, in *krm.BigtableAuthorizedViewSpec) *pb.AuthorizedView
func BigtableBackupObservedState_FromProto ¶ added in v1.130.1
func BigtableBackupObservedState_FromProto(mapCtx *direct.MapContext, in *pb.Backup) *krm.BigtableBackupObservedState
func BigtableBackupObservedState_ToProto ¶ added in v1.130.1
func BigtableBackupObservedState_ToProto(mapCtx *direct.MapContext, in *krm.BigtableBackupObservedState) *pb.Backup
func BigtableBackupSpec_FromProto ¶ added in v1.130.1
func BigtableBackupSpec_FromProto(mapCtx *direct.MapContext, in *pb.Backup) *krm.BigtableBackupSpec
func BigtableBackupSpec_ToProto ¶ added in v1.130.1
func BigtableBackupSpec_ToProto(mapCtx *direct.MapContext, in *krm.BigtableBackupSpec) *pb.Backup
func BigtableClusterFuzzer ¶ added in v1.130.1
func BigtableClusterFuzzer() fuzztesting.KRMFuzzer
func BigtableClusterObservedState_FromProto ¶ added in v1.130.1
func BigtableClusterObservedState_FromProto(mapCtx *direct.MapContext, in *pb.Cluster) *krm.BigtableClusterObservedState
func BigtableClusterObservedState_ToProto ¶ added in v1.130.1
func BigtableClusterObservedState_ToProto(mapCtx *direct.MapContext, in *krm.BigtableClusterObservedState) *pb.Cluster
func BigtableClusterSpec_FromProto ¶ added in v1.130.1
func BigtableClusterSpec_FromProto(mapCtx *direct.MapContext, in *pb.Cluster) *krm.BigtableClusterSpec
func BigtableClusterSpec_ToProto ¶ added in v1.130.1
func BigtableClusterSpec_ToProto(mapCtx *direct.MapContext, in *krm.BigtableClusterSpec) *pb.Cluster
func BigtableInstanceSpec_FromProto ¶
func BigtableInstanceSpec_FromProto(mapCtx *direct.MapContext, in *pb.Instance) *krm.BigtableInstanceSpec
func BigtableInstanceSpec_ToProto ¶
func BigtableInstanceSpec_ToProto(mapCtx *direct.MapContext, in *krm.BigtableInstanceSpec) *pb.Instance
func BigtableLogicalViewObservedState_FromProto ¶ added in v1.133.0
func BigtableLogicalViewObservedState_FromProto(mapCtx *direct.MapContext, in *pb.LogicalView) *krmv1alpha1.BigtableLogicalViewObservedState
func BigtableLogicalViewObservedState_ToProto ¶ added in v1.133.0
func BigtableLogicalViewObservedState_ToProto(mapCtx *direct.MapContext, in *krmv1alpha1.BigtableLogicalViewObservedState) *pb.LogicalView
func BigtableLogicalViewSpec_FromProto ¶ added in v1.133.0
func BigtableLogicalViewSpec_FromProto(mapCtx *direct.MapContext, in *pb.LogicalView) *krmv1alpha1.BigtableLogicalViewSpec
func BigtableLogicalViewSpec_ToProto ¶ added in v1.133.0
func BigtableLogicalViewSpec_ToProto(mapCtx *direct.MapContext, in *krmv1alpha1.BigtableLogicalViewSpec) *pb.LogicalView
func ChangeStreamConfig_RetentionPeriod_FromProto ¶
func ChangeStreamConfig_RetentionPeriod_FromProto(mapCtx *direct.MapContext, in *durationpb.Duration) *string
func ChangeStreamConfig_RetentionPeriod_ToProto ¶
func ChangeStreamConfig_RetentionPeriod_ToProto(mapCtx *direct.MapContext, in *string) *durationpb.Duration
func Cluster_ClusterAutoscalingConfig_FromProto ¶
func Cluster_ClusterAutoscalingConfig_FromProto(mapCtx *direct.MapContext, in *pb.Cluster_ClusterAutoscalingConfig) *krm.Cluster_ClusterAutoscalingConfig
func Cluster_ClusterAutoscalingConfig_ToProto ¶
func Cluster_ClusterAutoscalingConfig_ToProto(mapCtx *direct.MapContext, in *krm.Cluster_ClusterAutoscalingConfig) *pb.Cluster_ClusterAutoscalingConfig
func Cluster_ClusterConfig_FromProto ¶
func Cluster_ClusterConfig_FromProto(mapCtx *direct.MapContext, in *pb.Cluster_ClusterConfig) *krm.Cluster_ClusterConfig
func Cluster_ClusterConfig_ToProto ¶
func Cluster_ClusterConfig_ToProto(mapCtx *direct.MapContext, in *krm.Cluster_ClusterConfig) *pb.Cluster_ClusterConfig
func Cluster_EncryptionConfig_FromProto ¶
func Cluster_EncryptionConfig_FromProto(mapCtx *direct.MapContext, in *pb.Cluster_EncryptionConfig) *krm.Cluster_EncryptionConfig
func Cluster_EncryptionConfig_ToProto ¶
func Cluster_EncryptionConfig_ToProto(mapCtx *direct.MapContext, in *krm.Cluster_EncryptionConfig) *pb.Cluster_EncryptionConfig
func EncryptionInfoObservedState_FromProto ¶ added in v1.130.1
func EncryptionInfoObservedState_FromProto(mapCtx *direct.MapContext, in *pb.EncryptionInfo) *krm.EncryptionInfoObservedState
func EncryptionInfoObservedState_ToProto ¶ added in v1.130.1
func EncryptionInfoObservedState_ToProto(mapCtx *direct.MapContext, in *krm.EncryptionInfoObservedState) *pb.EncryptionInfo
func EncryptionInfo_EncryptionStatus_FromProto ¶
func EncryptionInfo_EncryptionStatus_FromProto(mapCtx *direct.MapContext, in *status.Status) *string
func EncryptionInfo_EncryptionStatus_ToProto ¶
func EncryptionInfo_EncryptionStatus_ToProto(mapCtx *direct.MapContext, in *string) *status.Status
func EncryptionInfo_FromProto ¶
func EncryptionInfo_FromProto(mapCtx *direct.MapContext, in *pb.EncryptionInfo) *krmv1beta1.EncryptionInfo
func EncryptionInfo_ToProto ¶
func EncryptionInfo_ToProto(mapCtx *direct.MapContext, in *krmv1beta1.EncryptionInfo) *pb.EncryptionInfo
func GcRule_MaxAge_FromProto ¶
func GcRule_MaxAge_FromProto(mapCtx *direct.MapContext, in *durationpb.Duration) *string
func GcRule_MaxAge_ToProto ¶
func GcRule_MaxAge_ToProto(mapCtx *direct.MapContext, in *string) *durationpb.Duration
func GcRule_MaxNumVersions_ToProto ¶
func GcRule_MaxNumVersions_ToProto(mapCtx *direct.MapContext, in *int32) *pb.GcRule_MaxNumVersions
func HasHTTPCode ¶
HasHTTPCode returns true if the given error is an HTTP response with the given code.
func HotTablet_EndTime_FromProto ¶
func HotTablet_EndTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func HotTablet_EndTime_ToProto ¶
func HotTablet_EndTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func HotTablet_StartTime_FromProto ¶
func HotTablet_StartTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func HotTablet_StartTime_ToProto ¶
func HotTablet_StartTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func Instance_CreateTime_FromProto ¶
func Instance_CreateTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func Instance_CreateTime_ToProto ¶
func Instance_CreateTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func Instance_SatisfiesPzs_ToProto ¶
func Instance_SatisfiesPzs_ToProto(mapCtx *direct.MapContext, in *bool) *bool
func IsNotFound ¶
IsNotFound returns true if the given error is an HTTP 404.
func NewBigtableAppProfileModel ¶ added in v1.132.0
func NewBigtableAppProfileModel(ctx context.Context, config *config.ControllerConfig) (directbase.Model, error)
func NewLogicalViewModel ¶ added in v1.133.0
func NewLogicalViewModel(ctx context.Context, config *config.ControllerConfig) (directbase.Model, error)
func OperationProgress_EndTime_FromProto ¶
func OperationProgress_EndTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func OperationProgress_EndTime_ToProto ¶
func OperationProgress_EndTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func OperationProgress_StartTime_FromProto ¶
func OperationProgress_StartTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func OperationProgress_StartTime_ToProto ¶
func OperationProgress_StartTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func Snapshot_CreateTime_FromProto ¶
func Snapshot_CreateTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func Snapshot_CreateTime_ToProto ¶
func Snapshot_CreateTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
func Snapshot_DeleteTime_FromProto ¶
func Snapshot_DeleteTime_FromProto(mapCtx *direct.MapContext, in *timestamppb.Timestamp) *string
func Snapshot_DeleteTime_ToProto ¶
func Snapshot_DeleteTime_ToProto(mapCtx *direct.MapContext, in *string) *timestamppb.Timestamp
Types ¶
type BigtableAppProfileAdapter ¶ added in v1.132.0
type BigtableAppProfileAdapter struct {
// contains filtered or unexported fields
}
func (*BigtableAppProfileAdapter) Create ¶ added in v1.132.0
func (a *BigtableAppProfileAdapter) Create(ctx context.Context, createOp *directbase.CreateOperation) error
Create creates the resource in GCP based on `spec` and update the Config Connector object `status` based on the GCP response.
func (*BigtableAppProfileAdapter) Delete ¶ added in v1.132.0
func (a *BigtableAppProfileAdapter) Delete(ctx context.Context, deleteOp *directbase.DeleteOperation) (bool, error)
Delete the resource from GCP service when the corresponding Config Connector resource is deleted.
func (*BigtableAppProfileAdapter) Export ¶ added in v1.132.0
func (a *BigtableAppProfileAdapter) Export(ctx context.Context) (*unstructured.Unstructured, error)
Export maps the GCP object to a Config Connector resource `spec`.
func (*BigtableAppProfileAdapter) Find ¶ added in v1.132.0
func (a *BigtableAppProfileAdapter) Find(ctx context.Context) (bool, error)
Find retrieves the GCP resource. Return true means the object is found. This triggers Adapter `Update` call. Return false means the object is not found. This triggers Adapter `Create` call. Return a non-nil error requeues the requests.
func (*BigtableAppProfileAdapter) Update ¶ added in v1.132.0
func (a *BigtableAppProfileAdapter) Update(ctx context.Context, updateOp *directbase.UpdateOperation) error
Update updates the resource in GCP based on `spec` and update the Config Connector object `status` based on the GCP response.
type LogicalViewAdapter ¶ added in v1.133.0
type LogicalViewAdapter struct {
// contains filtered or unexported fields
}
func (*LogicalViewAdapter) Create ¶ added in v1.133.0
func (a *LogicalViewAdapter) Create(ctx context.Context, createOp *directbase.CreateOperation) error
Create creates the resource in GCP based on `spec` and update the Config Connector object `status` based on the GCP response.
func (*LogicalViewAdapter) Delete ¶ added in v1.133.0
func (a *LogicalViewAdapter) Delete(ctx context.Context, deleteOp *directbase.DeleteOperation) (bool, error)
Delete the resource from GCP service when the corresponding Config Connector resource is deleted.
func (*LogicalViewAdapter) Export ¶ added in v1.133.0
func (a *LogicalViewAdapter) Export(ctx context.Context) (*unstructured.Unstructured, error)
Export maps the GCP object to a Config Connector resource `spec`.
func (*LogicalViewAdapter) Find ¶ added in v1.133.0
func (a *LogicalViewAdapter) Find(ctx context.Context) (bool, error)
Find retrieves the GCP resource. Return true means the object is found. This triggers Adapter `Update` call. Return false means the object is not found. This triggers Adapter `Create` call. Return a non-nil error requeues the requests.
func (*LogicalViewAdapter) Update ¶ added in v1.133.0
func (a *LogicalViewAdapter) Update(ctx context.Context, updateOp *directbase.UpdateOperation) error
Update updates the resource in GCP based on `spec` and update the Config Connector object `status` based on the GCP response.